(function() {

    'use strict';

    angular.module('myApp.customer.list.ctrls', [])
        .controller('CustomerViewCtrl', function($scope, $state, $ionicActionSheet, $ionicPopup, $ionicListDelegate, $ionicLoading, CustomerSvc) {
            var customerViewCtrl = this;

            customerViewCtrl.ionicListDelegate  =
                $ionicListDelegate.$getByHandle('customer-list');
            customerViewCtrl.searchString       = '';

            customerViewCtrl.moveItem = function(item, fromIndex, toIndex) {
                customerViewCtrl.listOfCustomers.splice(fromIndex, 1);
                customerViewCtrl.listOfCustomers.splice(toIndex, 0, item);
            };

            customerViewCtrl.updateCustomer = function(custNum) {
                customerViewCtrl.ionicListDelegate.closeOptionButtons();
                $state.go('app.custupdate', {custNum: custNum});
            };

            customerViewCtrl.deleteCustomer = function(custNum) {
                customerViewCtrl.ionicListDelegate.closeOptionButtons();
                var deleteCustomer = customerViewCtrl.listOfCustomersIdx[custNum],
                    confirmPopup = $ionicPopup.confirm({
                    title: 'Delete Customer',
                    template: 'Are you sure you want to delete "' + deleteCustomer.Name + '" customer?'
                });
                return confirmPopup.then(function(res) {
                    if (res) {
                        $ionicLoading.show({
                            template: 'Deleting...'
                        });
                        CustomerSvc.deleteCustomer(deleteCustomer).then(function() {
                            customerViewCtrl.listOfCustomers.splice(customerViewCtrl.listOfCustomers.indexOf(deleteCustomer), 1);
                        }).finally(function() {
                            $ionicLoading.hide();
                        });
                    }
                    return res;
                });
            };

            customerViewCtrl.loadCustomers = function() {
                return CustomerSvc.loadCustomers().then(function(listOfCustomers) {
                    customerViewCtrl.listOfCustomers = listOfCustomers;
                    customerViewCtrl.listOfCustomersIdx = {};
                    angular.forEach(customerViewCtrl.listOfCustomers, function(customer) {
                        customerViewCtrl.listOfCustomersIdx[customer.CustNum] = customer;
                    });
                })
                .finally(function() {
                    // Stop the ion-refresher from spinning
                    $scope.$broadcast('scroll.refreshComplete');
                });
            };

            customerViewCtrl.showOptions = function(custNum) {
                $ionicActionSheet.show({
                    buttons: [
                        { text: 'Show Orders' }
                    ],
                    destructiveText: 'Delete',
                    titleText: 'Customer Options',
                    cancelText: 'Cancel',
                    cancel: function() {
                        return true;
                    },
                    destructiveButtonClicked: function() {
                        customerViewCtrl.deleteCustomer(custNum);
                        return true;
                    },
                    buttonClicked: function(index) {
                        customerViewCtrl.ionicListDelegate.closeOptionButtons();
                        $state.go('app.orderList', {custNum: custNum});
                        return true;
                    }
                });
            };

            customerViewCtrl.loadCustomers();

        });

})();
